@@ -25,7 +25,10 @@ const defaultSchedule = "30 3,9,15,21 * * *"
 func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCuration() (err error) {
 
 	cluster := clusterRequest.cluster
-
+	if cluster.Spec.Curation == nil || cluster.Spec.Curation.Type == "" {
+		clusterRequest.removeCurator()
+		return nil
+	}
 	if cluster.Spec.Curation.Type == logging.CurationTypeCurator {
 
 		if err = clusterRequest.createOrUpdateCuratorServiceAccount(); err != nil {
@@ -52,26 +55,60 @@ func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateCuration() (err error
 
 		printUpdateMessage := true
 		retryErr := retry.RetryOnConflict(retry.DefaultRetry, func() error {
-			if !reflect.DeepEqual(curatorStatus, cluster.Status.Curation.CuratorStatus) {
+
+			if !compareCuratorStatus(curatorStatus, cluster.Status.Curation.CuratorStatus) {
 				if printUpdateMessage {
 					logrus.Info("Updating status of Curator")
 					printUpdateMessage = false
 				}
 				cluster.Status.Curation.CuratorStatus = curatorStatus
-				return clusterRequest.Update(cluster)
+				return clusterRequest.UpdateStatus(cluster)
 			}
 			return nil
 		})
 		if retryErr != nil {
 			return fmt.Errorf("Failed to update Cluster Logging Curator status: %v", retryErr)
 		}
-	} else {
-		clusterRequest.removeCurator()
 	}
 
 	return nil
 }
 
+func compareCuratorStatus(lhs, rhs []logging.CuratorStatus) bool {
+	// there should only ever be a single curator status object
+	if len(lhs) != len(rhs) {
+		return false
+	}
+
+	if len(lhs) > 0 {
+		for index, _ := range lhs {
+			if lhs[index].CronJob != rhs[index].CronJob {
+				return false
+			}
+
+			if lhs[index].Schedule != rhs[index].Schedule {
+				return false
+			}
+
+			if lhs[index].Suspended != rhs[index].Suspended {
+				return false
+			}
+
+			if len(lhs[index].Conditions) != len(rhs[index].Conditions) {
+				return false
+			}
+
+			if len(lhs[index].Conditions) > 0 {
+				if !reflect.DeepEqual(lhs[index].Conditions, rhs[index].Conditions) {
+					return false
+				}
+			}
+		}
+	}
+
+	return true
+}
+
 func (clusterRequest *ClusterLoggingRequest) removeCurator() (err error) {
 	if clusterRequest.isManaged() {
 		if err = clusterRequest.RemoveSecret("curator"); err != nil {
@@ -156,7 +193,11 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateCuratorSecret() error
 //TODO: refactor elasticsearchHost to get from cluster
 func newCuratorCronJob(cluster *logging.ClusterLogging, curatorName string, elasticsearchHost string) *batch.CronJob {
 
-	var resources = cluster.Spec.Curation.Resources
+	curationSpec := logging.CurationSpec{}
+	if cluster.Spec.Curation != nil {
+		curationSpec = *cluster.Spec.Curation
+	}
+	var resources = curationSpec.Resources
 	if resources == nil {
 		resources = &v1.ResourceRequirements{
 			Limits: v1.ResourceList{v1.ResourceMemory: defaultCuratorMemory},
@@ -193,14 +234,14 @@ func newCuratorCronJob(cluster *logging.ClusterLogging, curatorName string, elas
 			{Name: "config", VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "curator"}}}},
 			{Name: "certs", VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "curator"}}},
 		},
-		cluster.Spec.Curation.NodeSelector,
-		cluster.Spec.Curation.Tolerations,
+		curationSpec.NodeSelector,
+		curationSpec.Tolerations,
 	)
 
 	curatorPodSpec.RestartPolicy = v1.RestartPolicyNever
 	curatorPodSpec.TerminationGracePeriodSeconds = utils.GetInt64(600)
 
-	schedule := cluster.Spec.Curation.CuratorSpec.Schedule
+	schedule := curationSpec.CuratorSpec.Schedule
 	if schedule == "" {
 		schedule = defaultSchedule
 	}
