@@ -73,40 +73,6 @@ func (clusterRequest *ClusterLoggingRequest) getFluentdCollectorStatus() (loggin
 	return fluentdStatus, nil
 }
 
-func (clusterRequest *ClusterLoggingRequest) getRsyslogCollectorStatus() (logging.RsyslogCollectorStatus, error) {
-
-	rsyslogStatus := logging.RsyslogCollectorStatus{}
-	selector := map[string]string{
-		"logging-infra": "rsyslog",
-	}
-
-	rsyslogDaemonsetList, err := clusterRequest.GetDaemonSetList(selector)
-
-	if err != nil {
-		return rsyslogStatus, err
-	}
-
-	if len(rsyslogDaemonsetList.Items) != 0 {
-		daemonset := rsyslogDaemonsetList.Items[0]
-
-		rsyslogStatus.DaemonSet = daemonset.Name
-
-		// use map to represent {pod: node}
-		podList, _ := clusterRequest.GetPodList(selector)
-
-		podNodeMap := make(map[string]string)
-		for _, pod := range podList.Items {
-			podNodeMap[pod.Name] = pod.Spec.NodeName
-		}
-		rsyslogStatus.Pods = podStateMap(podList.Items)
-		rsyslogStatus.Nodes = podNodeMap
-
-		rsyslogStatus.Conditions = clusterRequest.getPodConditions("rsyslog")
-	}
-
-	return rsyslogStatus, nil
-}
-
 func (clusterRequest *ClusterLoggingRequest) getKibanaStatus() ([]logging.KibanaStatus, error) {
 
 	status := []logging.KibanaStatus{}
